==> laravel-scripts-0.1.19.tgz: package/tasks/tplLaravel.js <==
// @ts-check

/**
 * Manage laravel config folder
 */
function tplLaravelConfig() {
  const gulp = require("gulp");
  const { join, frontend, laravel } = require("../paths");

  return gulp
    .src(join(frontend.src.config, "**/*.php"), { base: frontend.src.config })
    .pipe(gulp.dest(laravel.app.config));
}

/**
 * Manage laravel public folder
 */
function tplLaravelPublic() {
  const gulp = require("gulp");
  const { join, laravel } = require("../paths");

  return gulp
    .src(join(laravel.lib.public, "**/*.php"), { base: laravel.lib.public })
    .pipe(gulp.dest(laravel.app.public));
}

/**
 * Manage laravel bootstrap folder
 */
function tplLaravelBootstrap() {
  const gulp = require("gulp");
  const { join, laravel } = require("../paths");

  return gulp
    .src(join(laravel.lib.bootstrap, "*.php"), { base: laravel.lib.bootstrap })
    .pipe(gulp.dest(laravel.app.bootstrap));
}

/**
 * Manage laravel bootstrap cache folder
 */
function tplLaravelBootstrapCache() {
  const gulp = require("gulp");
  const rename = require("gulp-rename");
  const { join, laravel, self } = require("../paths");

  return gulp
    .src(join(self.templates, "gitignore-folder"))
    .pipe(rename(".gitignore"))
    .pipe(gulp.dest(join(laravel.app.bootstrap, "cache")));
}

/**
 * Manage laravel storage cache folder
 *
 * @see https://github.com/laravel/laravel
 */
function tplLaravelStorage() {
  const gulp = require("gulp");
  const rename = require("gulp-rename");
  const { join, laravel, self } = require("../paths");

  return gulp
    .src(join(self.templates, "gitignore-folder"))
    .pipe(rename(".gitignore"))
    .pipe(gulp.dest(join(laravel.app.storage, "app")))
    .pipe(gulp.dest(join(laravel.app.storage, "app/public")))
    .pipe(gulp.dest(join(laravel.app.storage, "debugbar")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework/cache")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework/sessions")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework/testing")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework/views")))
    .pipe(gulp.dest(join(laravel.app.storage, "logs")));
}

/**
 * Manage laravel artisan file
 */
function tplLaravelArtisan() {
  const gulp = require("gulp");
  const { join, laravel } = require("../paths");

  return gulp
    .src(join(laravel.lib.base, "artisan"))
    .pipe(gulp.dest(laravel.app.base));
}

/**
 * Collect subtasks in a single task that respect the gulp async lifecycle by
 * calling the callback on completion.
 */
module.exports = function tplLaravel(callback) {
  const gulp = require("gulp");

  return gulp.series(
    // tplLaravelConfig,
    tplLaravelPublic,
    tplLaravelBootstrap,
    tplLaravelBootstrapCache,
    tplLaravelStorage,
    tplLaravelArtisan
  )(callback);
};

==> laravel-scripts-0.1.39.tgz: package/tasks/tplLaravel.js <==
// @ts-check

/**
 * Manage laravel config folder
 */
function tplLaravelConfig() {
  const gulp = require("gulp");
  const { join, frontend, laravel } = require("../paths");

  return gulp
    .src(join(frontend.src.config, "**/*.php"), { base: frontend.src.config })
    .pipe(gulp.dest(laravel.app.config));
}

/**
 * Manage laravel public folder
 */
function tplLaravelPublic() {
  const gulp = require("gulp");
  const { join, laravel } = require("../paths");

  return gulp
    .src(join(laravel.tpl.public, "**/*.php"), { base: laravel.tpl.public })
    .pipe(gulp.dest(laravel.app.public));
}

/**
 * Manage laravel bootstrap folder
 */
function tplLaravelBootstrap() {
  const gulp = require("gulp");
  const { join, laravel } = require("../paths");

  return gulp
    .src(join(laravel.tpl.bootstrap, "*.php"), { base: laravel.tpl.bootstrap })
    .pipe(gulp.dest(laravel.app.bootstrap));
}

/**
 * Manage laravel bootstrap cache folder
 */
function tplLaravelBootstrapCache() {
  const gulp = require("gulp");
  const rename = require("gulp-rename");
  const { join, laravel, self } = require("../paths");

  return gulp
    .src(join(self.templates, "gitignore-folder"))
    .pipe(rename(".gitignore"))
    .pipe(gulp.dest(join(laravel.app.bootstrap, "cache")));
}

/**
 * Manage laravel storage cache folder
 *
 * @see https://github.com/laravel/laravel
 */
function tplLaravelStorage() {
  const gulp = require("gulp");
  const rename = require("gulp-rename");
  const { join, laravel, self } = require("../paths");

  return gulp
    .src(join(self.templates, "gitignore-folder"))
    .pipe(rename(".gitignore"))
    .pipe(gulp.dest(join(laravel.app.storage, "app")))
    .pipe(gulp.dest(join(laravel.app.storage, "app/public")))
    .pipe(gulp.dest(join(laravel.app.storage, "debugbar")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework/cache")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework/sessions")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework/testing")))
    .pipe(gulp.dest(join(laravel.app.storage, "framework/views")))
    .pipe(gulp.dest(join(laravel.app.storage, "logs")));
}

/**
 * Manage laravel artisan file
 */
function tplLaravelArtisan() {
  const gulp = require("gulp");
  const { join, laravel } = require("../paths");

  return gulp
    .src(join(laravel.tpl.base, "artisan"))
    .pipe(gulp.dest(laravel.app.base));
}

/**
 * Collect subtasks in a single task that respect the gulp async lifecycle by
 * calling the callback on completion.
 */
module.exports = function tplLaravel(callback) {
  const gulp = require("gulp");

  return gulp.series(
    // tplLaravelConfig,
    tplLaravelPublic,
    tplLaravelBootstrap,
    tplLaravelBootstrapCache,
    tplLaravelStorage,
    tplLaravelArtisan
  )(callback);
};
